[![PyPI version](https://badge.fury.io/py/bento-tools.svg)](https://badge.fury.io/py/bento-tools)
[![codecov](https://codecov.io/gh/ckmah/bento-tools/branch/master/graph/badge.svg?token=XVHDKNDCDT)](https://codecov.io/gh/ckmah/bento-tools)
[![Documentation Status](https://readthedocs.org/projects/bento-tools/badge/?version=latest)](https://bento-tools.readthedocs.io/en/latest/?badge=latest)
[![Downloads](https://static.pepy.tech/badge/bento-tools)](https://pepy.tech/project/bento-tools)
![PyPI - Downloads](https://img.shields.io/pypi/dm/bento-tools)
[![GitHub stars](https://badgen.net/github/stars/ckmah/bento-tools)](https://GitHub.com/Naereen/ckmah/bento-tools) 
[![project chat](https://img.shields.io/badge/zulip-join_chat-brightgreen.svg)](https://scverse.zulip.com)
# Bento

Bento is a Python toolkit for performing subcellular analysis of spatial transcriptomics data. The package is part of the [Scverse ecosystem](https://scverse.org/packages/#ecosystem). Check out the [documentation](https://bento-tools.readthedocs.io/en/latest/) for installation instructions, tutorials, and API. For questions and troubleshooting, visit the `#bento` stream @ the [Scverse Zulip chat](https://scverse.zulip.com)!

Cite [our paper](https://doi.org/10.1101/2022.06.10.495510) if you use Bento in your work. Thanks!

<img src="docs/source/_static/tutorial_img/bento_tools.png" alt="Bento Workflow" width="800">

---
[![GitHub license](https://img.shields.io/github/license/ckmah/bento-tools.svg)](https://github.com/ckmah/bento-tools/blob/master/LICENSE)
